@@ -160,6 +160,9 @@ m4_pushdef([b4_parse_param], m4_defn([b4_parse_param_orig]))dnl
   ]b4_parser_class::~b4_parser_class[ ()
   {}
 
+  ]b4_parser_class[::syntax_error::~syntax_error () YY_NOEXCEPT YY_NOTHROW
+  {}
+
   int
   ]b4_parser_class[::operator() ()
   {
@@ -246,9 +249,12 @@ b4_percent_code_get([[requires]])[
 #include <stdexcept>
 #include <string>
 
-]m4_ifdef([b4_location_file],
+]b4_cxx_portability[
+]m4_ifdef([b4_location_include],
           [[# include ]b4_location_include])[
+]b4_variant_if([b4_variant_includes])[
 
+]b4_attribute_define[
 ]b4_null_define[
 
 // Whether we are compiled with exception support.
@@ -263,6 +269,7 @@ b4_percent_code_get([[requires]])[
 ]b4_YYDEBUG_define[
 
 ]b4_namespace_open[
+
 ]b4_bison_locations_if([m4_ifndef([b4_location_file],
                                   [b4_location_define])])[
 
