@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.2.1.140-ce94f.  */
+/* A Bison parser, made by GNU Bison 3.2.91.31-64be.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -47,7 +48,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.2.1.140-ce94f"
+#define YYBISON_VERSION "3.2.91.31-64be"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -67,7 +68,7 @@
 #include <stdio.h>  /* printf. */
 #include <stdlib.h> /* getenv. */
 
-#line 71 "examples/c/lexcalc/parse.c" /* yacc.c:315  */
+#line 72 "examples/c/lexcalc/parse.c" /* yacc.c:315  */
 
 
 
@@ -133,7 +134,7 @@ union YYSTYPE
   int TOK_line;
   /* exp  */
   int TOK_exp;
-#line 137 "examples/c/lexcalc/parse.c" /* yacc.c:352  */
+#line 138 "examples/c/lexcalc/parse.c" /* yacc.c:352  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -154,7 +155,7 @@ int yyparse (int *nerrs);
 
   void yyerror (int *nerrs, const char *msg);
 
-#line 158 "examples/c/lexcalc/parse.c" /* yacc.c:352  */
+#line 159 "examples/c/lexcalc/parse.c" /* yacc.c:352  */
 
 #endif /* !YY_YY_EXAMPLES_C_LEXCALC_PARSE_H_INCLUDED  */
 
@@ -457,8 +458,9 @@ static const yytype_uint8 yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
 {
-  "end-of-file", "error", "$undefined", "+", "-", "*", "/", "(", ")",
-  "end-of-line", "number", "$accept", "input", "line", "exp", YY_NULLPTR
+  "\"end-of-file\"", "error", "$undefined", "\"+\"", "\"-\"", "\"*\"",
+  "\"/\"", "\"(\"", "\")\"", "\"end-of-line\"", "\"number\"", "$accept",
+  "input", "line", "exp", YY_NULLPTR
 };
 #endif
 
@@ -639,19 +641,19 @@ yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, in
     case 10: /* "number"  */
 #line 43 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:680  */
       { fprintf (yyo, "%d", ((*yyvaluep).TOK_NUM)); }
-#line 643 "examples/c/lexcalc/parse.c" /* yacc.c:680  */
+#line 645 "examples/c/lexcalc/parse.c" /* yacc.c:680  */
         break;
 
     case 13: /* line  */
 #line 43 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:680  */
       { fprintf (yyo, "%d", ((*yyvaluep).TOK_line)); }
-#line 649 "examples/c/lexcalc/parse.c" /* yacc.c:680  */
+#line 651 "examples/c/lexcalc/parse.c" /* yacc.c:680  */
         break;
 
     case 14: /* exp  */
 #line 43 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:680  */
       { fprintf (yyo, "%d", ((*yyvaluep).TOK_exp)); }
-#line 655 "examples/c/lexcalc/parse.c" /* yacc.c:680  */
+#line 657 "examples/c/lexcalc/parse.c" /* yacc.c:680  */
         break;
 
       default:
@@ -805,6 +807,39 @@ yystpcpy (char *yydest, const char *yysrc)
 static YYSIZE_T
 yytnamerr (char *yyres, const char *yystr)
 {
+  if (*yystr == '"')
+    {
+      YYSIZE_T yyn = 0;
+      char const *yyp = yystr;
+
+      for (;;)
+        switch (*++yyp)
+          {
+          case '\'':
+          case ',':
+            goto do_not_strip_quotes;
+
+          case '\\':
+            if (*++yyp != '\\')
+              goto do_not_strip_quotes;
+            else
+              goto append;
+
+          append:
+          default:
+            if (yyres)
+              yyres[yyn] = *yyp;
+            yyn++;
+            break;
+
+          case '"':
+            if (yyres)
+              yyres[yyn] = '\0';
+            return yyn;
+          }
+    do_not_strip_quotes: ;
+    }
+
   if (! yyres)
     return yystrlen (yystr);
 
@@ -886,10 +921,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -913,9 +948,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1227,43 +1263,43 @@ yyreduce:
   switch (yyn)
     {
         case 3:
-#line 53 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1618  */
+#line 53 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1652  */
     { printf ("%d\n", (yyvsp[0].TOK_line)); }
-#line 1233 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1269 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
     break;
 
   case 4:
-#line 57 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1618  */
+#line 57 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1652  */
     { (yyval.TOK_line) = (yyvsp[-1].TOK_exp); }
-#line 1239 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1275 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
     break;
 
   case 5:
-#line 58 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1618  */
+#line 58 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1652  */
     { yyerrok; }
-#line 1245 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1281 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
     break;
 
   case 6:
-#line 62 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1618  */
+#line 62 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1652  */
     { (yyval.TOK_exp) = (yyvsp[-2].TOK_exp) + (yyvsp[0].TOK_exp);  }
-#line 1251 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1287 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
     break;
 
   case 7:
-#line 63 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1618  */
+#line 63 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1652  */
     { (yyval.TOK_exp) = (yyvsp[-2].TOK_exp) - (yyvsp[0].TOK_exp);  }
-#line 1257 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1293 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
     break;
 
   case 8:
-#line 64 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1618  */
+#line 64 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1652  */
     { (yyval.TOK_exp) = (yyvsp[-2].TOK_exp) * (yyvsp[0].TOK_exp);  }
-#line 1263 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1299 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
     break;
 
   case 9:
-#line 66 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1618  */
+#line 66 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1652  */
     {
     if ((yyvsp[0].TOK_exp) == 0)
       {
@@ -1273,23 +1309,23 @@ yyreduce:
     else
       (yyval.TOK_exp) = (yyvsp[-2].TOK_exp) / (yyvsp[0].TOK_exp);
   }
-#line 1277 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1313 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
     break;
 
   case 10:
-#line 75 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1618  */
+#line 75 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1652  */
     { (yyval.TOK_exp) = (yyvsp[-1].TOK_exp);       }
-#line 1283 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1319 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
     break;
 
   case 11:
-#line 76 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1618  */
+#line 76 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1652  */
     { (yyval.TOK_exp) = (yyvsp[0].TOK_NUM); }
-#line 1289 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1325 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
     break;
 
 
-#line 1293 "examples/c/lexcalc/parse.c" /* yacc.c:1618  */
+#line 1329 "examples/c/lexcalc/parse.c" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1520,7 +1556,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 78 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1884  */
+#line 78 "/Users/akim/src/gnu/bison/examples/c/lexcalc/parse.y" /* yacc.c:1918  */
 
 // Epilogue (C code).
 void yyerror(int *nerrs, const char *msg)
