@@ -1,7 +1,7 @@
 /* Closures for Bison
 
-   Copyright (C) 1984, 1989, 2000-2002, 2004-2005, 2007, 2009-2015, 2018
-   Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 2000-2002, 2004-2005, 2007, 2009-2015,
+   2018-2019 Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -22,7 +22,6 @@
 #include "system.h"
 
 #include <bitset.h>
-#include <bitsetv-print.h>
 #include <bitsetv.h>
 
 #include "closure.h"
