@@ -287,7 +287,7 @@ Operation modes:\n\
                              and exit\n\
       --print-datadir        output directory containing skeletons and XSLT\n\
                              and exit\n\
-  -u, --update               apply fixes to the source grammar file\n\
+  -u, --update               apply fixes to the source grammar file and exit\n\
   -y, --yacc                 emulate POSIX Yacc\n\
   -W, --warnings[=CATEGORY]  report the warnings falling in CATEGORY\n\
   -f, --feature[=FEATURE]    activate miscellaneous features\n\
