@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.1.91.31-00793.  */
+/* A Bison parser, made by GNU Bison 3.2.90.23-0bbcb-dirty.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -51,11 +52,11 @@
 extern int gram_debug;
 #endif
 /* "%code requires" blocks.  */
-#line 21 "src/parse-gram.y" /* yacc.c:1906  */
+#line 21 "src/parse-gram.y" /* yacc.c:1921  */
 
   #include "symlist.h"
   #include "symtab.h"
-#line 222 "src/parse-gram.y" /* yacc.c:1906  */
+#line 239 "src/parse-gram.y" /* yacc.c:1921  */
 
   typedef enum
   {
@@ -64,10 +65,16 @@ extern int gram_debug;
     param_parse  = 1 << 1,
     param_both   = param_lex | param_parse
   } param_type;
-#line 645 "src/parse-gram.y" /* yacc.c:1906  */
-#include "muscle-tab.h"
+#line 682 "src/parse-gram.y" /* yacc.c:1921  */
 
-#line 71 "src/parse-gram.h" /* yacc.c:1906  */
+  #include "muscle-tab.h"
+  typedef struct
+  {
+    char const *chars;
+    muscle_kind kind;
+  } value_type;
+
+#line 78 "src/parse-gram.h" /* yacc.c:1921  */
 
 /* Token type.  */
 #ifndef GRAM_TOKENTYPE
@@ -138,35 +145,90 @@ extern int gram_debug;
 
 union GRAM_STYPE
 {
-#line 183 "src/parse-gram.y" /* yacc.c:1906  */
-unsigned char character;
-#line 187 "src/parse-gram.y" /* yacc.c:1906  */
-char *code;
-#line 192 "src/parse-gram.y" /* yacc.c:1906  */
-uniqstr uniqstr;
-#line 200 "src/parse-gram.y" /* yacc.c:1906  */
-int integer;
-#line 204 "src/parse-gram.y" /* yacc.c:1906  */
-symbol *symbol;
-#line 209 "src/parse-gram.y" /* yacc.c:1906  */
-assoc assoc;
-#line 212 "src/parse-gram.y" /* yacc.c:1906  */
-symbol_list *list;
-#line 215 "src/parse-gram.y" /* yacc.c:1906  */
-named_ref *named_ref;
-#line 242 "src/parse-gram.y" /* yacc.c:1906  */
-param_type param;
-#line 409 "src/parse-gram.y" /* yacc.c:1906  */
-code_props_type code_type;
-#line 647 "src/parse-gram.y" /* yacc.c:1906  */
 
-  struct
-  {
-    char const *chars;
-    muscle_kind kind;
-  } value;
-
-#line 170 "src/parse-gram.h" /* yacc.c:1906  */
+  /* precedence_declarator  */
+  assoc precedence_declarator;
+  /* "string"  */
+  char* STRING;
+  /* "{...}"  */
+  char* BRACED_CODE;
+  /* "%?{...}"  */
+  char* BRACED_PREDICATE;
+  /* "epilogue"  */
+  char* EPILOGUE;
+  /* "%{...%}"  */
+  char* PROLOGUE;
+  /* code_props_type  */
+  code_props_type code_props_type;
+  /* "integer"  */
+  int INT;
+  /* int.opt  */
+  int yytype_79;
+  /* named_ref.opt  */
+  named_ref* yytype_91;
+  /* "%param"  */
+  param_type PERCENT_PARAM;
+  /* token_decl  */
+  symbol* token_decl;
+  /* token_decl_for_prec  */
+  symbol* token_decl_for_prec;
+  /* id  */
+  symbol* id;
+  /* id_colon  */
+  symbol* id_colon;
+  /* symbol  */
+  symbol* symbol;
+  /* string_as_id  */
+  symbol* string_as_id;
+  /* string_as_id.opt  */
+  symbol* yytype_98;
+  /* generic_symlist  */
+  symbol_list* generic_symlist;
+  /* generic_symlist_item  */
+  symbol_list* generic_symlist_item;
+  /* nterm_decls  */
+  symbol_list* nterm_decls;
+  /* token_decls  */
+  symbol_list* token_decls;
+  /* token_decl.1  */
+  symbol_list* yytype_77;
+  /* token_decls_for_prec  */
+  symbol_list* token_decls_for_prec;
+  /* token_decl_for_prec.1  */
+  symbol_list* yytype_81;
+  /* symbol_decls  */
+  symbol_list* symbol_decls;
+  /* symbol_decl.1  */
+  symbol_list* yytype_84;
+  /* "%error-verbose"  */
+  uniqstr PERCENT_ERROR_VERBOSE;
+  /* "%<flag>"  */
+  uniqstr PERCENT_FLAG;
+  /* "%file-prefix"  */
+  uniqstr PERCENT_FILE_PREFIX;
+  /* "%name-prefix"  */
+  uniqstr PERCENT_NAME_PREFIX;
+  /* "%yacc"  */
+  uniqstr PERCENT_YACC;
+  /* "[identifier]"  */
+  uniqstr BRACKETED_ID;
+  /* "identifier"  */
+  uniqstr ID;
+  /* "identifier:"  */
+  uniqstr ID_COLON;
+  /* "<tag>"  */
+  uniqstr TAG;
+  /* tag.opt  */
+  uniqstr yytype_71;
+  /* tag  */
+  uniqstr tag;
+  /* variable  */
+  uniqstr variable;
+  /* "char"  */
+  unsigned char CHAR;
+  /* value  */
+  value_type value;
+#line 232 "src/parse-gram.h" /* yacc.c:1921  */
 };
 
 typedef union GRAM_STYPE GRAM_STYPE;
